@@ -14,7 +14,8 @@ def write_schema(catalog, stream_name):
     try:
         singer.write_schema(stream_name, schema, stream.key_properties)
     except OSError as err:
-        LOGGER.info('OS Error writing schema for: {}'.format(stream_name))
+        LOGGER.error('OS Error writing schema for: {}'.format(stream_name))
+        LOGGER.error('Error: {}'.format(err))
         raise err
 
 
@@ -22,8 +23,9 @@ def write_record(stream_name, record, time_extracted):
     try:
         singer.messages.write_record(stream_name, record, time_extracted=time_extracted)
     except OSError as err:
-        LOGGER.info('OS Error writing record for: {}'.format(stream_name))
-        LOGGER.info('record: {}'.format(record))
+        LOGGER.error('OS Error writing record for: {}'.format(stream_name))
+        LOGGER.error('record: {}'.format(record))
+        LOGGER.error('Error: {}'.format(err))
         raise err
 
 
@@ -49,12 +51,7 @@ def write_bookmark(state, stream, site, sub_type, value):
     state['bookmarks'][stream][site][sub_type] = value
     LOGGER.info('Write state for Stream: {}, Site: {}, Type: {}, value: {}'.format(
         stream, site, sub_type, value))
-    try:
-        singer.messages.write_state(state)
-    except OSError as err:
-        LOGGER.info('OS Error writing State for: {}'.format(stream))
-        LOGGER.info('state: {}'.format(state))
-        raise err
+    singer.write_state(state)
 
 
 def transform_datetime(this_dttm):
@@ -300,12 +297,7 @@ def update_currently_syncing(state, stream_name):
         del state['currently_syncing']
     else:
         singer.set_currently_syncing(state, stream_name)
-    try:
-        singer.messages.write_state(state)
-    except OSError as err:
-        LOGGER.info('OS Error writing Currently Syncing State for: {}'.format(stream_name))
-        LOGGER.info('state: {}'.format(state))
-        raise err
+    singer.write_state(state)
 
 
 def sync(client, config, catalog, state):
@@ -334,6 +326,7 @@ def sync(client, config, catalog, state):
         write_schema(catalog, stream_name)
         endpoint_config = STREAMS[stream_name]
         bookmark_field = next(iter(endpoint_config.get('replication_keys', [])), None)
+        body_params = endpoint_config.get('body', {})
         endpoint_total = 0
         # Initialize body
         body = endpoint_config.get('body', {})
@@ -342,68 +335,78 @@ def sync(client, config, catalog, state):
         if 'site_urls' in config:
             site_list = config['site_urls'].replace(" ", "").split(",")
         for site in site_list:
-            LOGGER.info('STARTED Syncing: {}, Site: {}'.format(stream_name, site))
-            site_total = 0
-            site_encoded = quote(site, safe='')
-            path = endpoint_config.get('path').format(site_encoded)
+            # Skip/ignore sitemaps for domain property sites
+            # Reference issue: https://github.com/googleapis/google-api-php-client/issues/1607
+            #   "...sitemaps API does not support domain property urls at this time."
+            if stream_name == 'sitemaps' and site[0:9] == 'sc-domain':
+                LOGGER.info('Skipping Site: {}'.format(site))
+                LOGGER.info('  Sitemaps API does not support domain property urls at this time.')
+            else:
+                LOGGER.info('STARTED Syncing: {}, Site: {}'.format(stream_name, site))
+                site_total = 0
+                site_encoded = quote(site, safe='')
+                path = endpoint_config.get('path').format(site_encoded)
 
-            # Set dimension_list for performance_reports
-            dimensions_list = []
-            if stream_name == 'performance_reports':
-                # Create dimensions_list from catalog breadcrumb
-                stream = catalog.get_stream(stream_name)
-                mdata = metadata.to_map(stream.metadata)
-                dimensions_all = ['date', 'country', 'device', 'page', 'query']
-                for dim in dimensions_all:
-                    if singer.metadata.get(mdata, ('properties', dim), 'selected'):
-                        # metadata is selected for the dimension
-                        dimensions_list.append(dim)
+                # Set dimension_list for performance_reports
+                if stream_name == 'performance_report_custom':
+                    dimensions_list = []
+                    # Create dimensions_list from catalog breadcrumb
+                    stream = catalog.get_stream(stream_name)
+                    mdata = metadata.to_map(stream.metadata)
+                    dimensions_all = ['date', 'country', 'device', 'page', 'query']
+                    for dim in dimensions_all:
+                        if singer.metadata.get(mdata, ('properties', dim), 'selected'):
+                            # metadata is selected for the dimension
+                            dimensions_list.append(dim)
+                    body_params['dimensions'] = dimensions_list
+                dimensions_list = body_params.get('dimensions')
+                LOGGER.info('stream: {}, dimensions_list: {}'.format(stream_name, dimensions_list))
 
-            # loop through each sub type
-            sub_types = endpoint_config.get('sub_types', ['self'])
-            for sub_type in sub_types:
-                if stream_name == 'performance_reports':
-                    reports_dttm_str = get_bookmark(
-                        state,
-                        stream_name,
-                        site,
-                        sub_type,
-                        start_date)
-                    reports_dt_str = transform_datetime(reports_dttm_str)[:10]
-                    body = {
-                        'dimensions': dimensions_list,
-                        'searchType': sub_type,
-                        'startDate': reports_dt_str,
-                        'endDate': now_dt_str
-                    }
+                # loop through each sub type
+                sub_types = endpoint_config.get('sub_types', ['self'])
+                for sub_type in sub_types:
+                    if stream_name.startswith('performance_report'):
+                        reports_dttm_str = get_bookmark(
+                            state,
+                            stream_name,
+                            site,
+                            sub_type,
+                            start_date)
+                        reports_dt_str = transform_datetime(reports_dttm_str)[:10]
+                        body = {
+                            'searchType': sub_type,
+                            'startDate': reports_dt_str,
+                            'endDate': now_dt_str,
+                            **body_params
+                        }
 
-                LOGGER.info('START Syncing Stream: {}, Site: {}, Type: {}'.format(
-                    stream_name, site, sub_type))
-                total_records = sync_endpoint(
-                    client=client,
-                    catalog=catalog,
-                    state=state,
-                    start_date=start_date,
-                    stream_name=stream_name,
-                    site=site,
-                    sub_type=sub_type,
-                    dimensions_list=dimensions_list,
-                    path=path,
-                    endpoint_config=endpoint_config,
-                    api_method=endpoint_config.get('api_method', 'GET'),
-                    pagination=endpoint_config.get('pagination', 'none'),
-                    static_params=endpoint_config.get('params', {}),
-                    bookmark_field=bookmark_field,
-                    bookmark_type=endpoint_config.get('bookmark_type'),
-                    data_key=endpoint_config.get('data_key', None),
-                    body_params=body,
-                    id_fields=endpoint_config.get('key_properties'))
+                    LOGGER.info('START Syncing Stream: {}, Site: {}, Type: {}'.format(
+                        stream_name, site, sub_type))
+                    total_records = sync_endpoint(
+                        client=client,
+                        catalog=catalog,
+                        state=state,
+                        start_date=start_date,
+                        stream_name=stream_name,
+                        site=site,
+                        sub_type=sub_type,
+                        dimensions_list=dimensions_list,
+                        path=path,
+                        endpoint_config=endpoint_config,
+                        api_method=endpoint_config.get('api_method', 'GET'),
+                        pagination=endpoint_config.get('pagination', 'none'),
+                        static_params=endpoint_config.get('params', {}),
+                        bookmark_field=bookmark_field,
+                        bookmark_type=endpoint_config.get('bookmark_type'),
+                        data_key=endpoint_config.get('data_key', None),
+                        body_params=body,
+                        id_fields=endpoint_config.get('key_properties'))
 
-                endpoint_total = endpoint_total + total_records
-                site_total = site_total + total_records
-                LOGGER.info('FINISHED Syncing Stream: {}, Site: {}, Type: {}'.format(
-                    stream_name, site, sub_type))
-                LOGGER.info('  Records Synced for Type: {}'.format(total_records))
+                    endpoint_total = endpoint_total + total_records
+                    site_total = site_total + total_records
+                    LOGGER.info('FINISHED Syncing Stream: {}, Site: {}, Type: {}'.format(
+                        stream_name, site, sub_type))
+                    LOGGER.info('  Records Synced for Type: {}'.format(total_records))
             LOGGER.info('FINISHED Syncing Stream: {}, Site: {}'.format(stream_name, site))
             LOGGER.info('  Records Synced for Site: {}'.format(site_total))
         LOGGER.info('FINISHED Syncing Stream: {}'.format(stream_name))
